% Compute the var of a call option
% given the various parameters using the historic VaR
% algorithm. Note we need some assumptions on the riskFreeRate
% and the vol after the given number of days in order to actually
% price the call option at the end, hence the last two parameters.
% You could also choose to estimate the volatility using EWMA.
function [ var ] = historicVar( ...
    percent,days, ...
    strike, maturity, ...
    spot, historicPrices, ...
    riskFreeRate, volatility)

dailyLogReturns = diff( log( historicPrices ));
dDayLogReturns = dailyLogReturns .* sqrt( days );
stockPrices = exp(dDayLogReturns) * spot;

t = days/365;
startPrice = blackScholesCallPrice( ...
    strike, maturity, ...
    spot,riskFreeRate, volatility ); % price portfolio at start
endPrices = blackScholesCallPrice( strike, maturity-t, ...
    stockPrices,riskFreeRate,volatility ); % price portfolio
profits = endPrices - startPrice;
var = prctile( -profits, 100-percent );

end

