% Compute the var of a call option
% given the various parameters using Monte Carlo
function [ estimate, lower, upper ] = monteCarloVarWithConfidence( ...
    confidence, ...
    percent,days, ...
    strike, maturity, ...
    spot, drift, volatility, ...
    riskFreeRate, ...
    nPaths)

t = days/365;
stockPrices = generateBSPaths( ...
    t, spot, drift, volatility,...
    nPaths, 1);
startPrice = blackScholesCallPrice( ...
    strike, maturity, ...
    spot,riskFreeRate, volatility );
endPrices = blackScholesCallPrice( strike, maturity-t, ...
    stockPrices,riskFreeRate,volatility );
profits = endPrices - startPrice;
alpha = percent/100;
beta = confidence/100;
r = percent + 100*sqrt(alpha*(1-alpha)/nPaths)*norminv((1-beta)/2);
s = percent - 100*sqrt(alpha*(1-alpha)/nPaths)*norminv((1-beta)/2);
estimate = prctile( -profits, 100-percent );
lower = prctile( -profits, 100-s );
upper = prctile( -profits, 100-r );

end

