function testAcme()

rng('default');

percentage = 5;
d = 10;
spot = 100;
vol = 0.2;
drift = vol^2/2;
r = vol^2/2;
nPaths = 1000000;

strike = 1; % We've got a very low strike throughout all the tests, so
            % we're effectively just measuring the stock
maturity = 101/365;

mVar = monteCarloVar( ...
    percentage,d, ...
    strike, maturity, ...
    spot, drift, vol, ...
    r, ...
    nPaths);
es = monteCarloES( ...
    percentage,d, ...
    strike, maturity, ...
    spot, drift, vol, ...
    r, ...
    nPaths);
trueVar = analyticalVar(...
    percentage,d, ...
    strike, maturity, ...
    spot, vol, ...
    r);
parametricVar = parametricCallVar(...
    percentage,d, ...
    strike, maturity, ...
    spot, vol, ...
    r);

% The ACME company isn't real. I generated some fake "historic data" using
% the code below. This is why for this example the "historic" VaR is
% approximately the same value as the Monte Carlo VaR. For a real stock
% they might be very different.
%
nDaysHistory = 10000;
historicPrices = generateBSPaths(nDaysHistory/365,100,drift,vol,1,nDaysHistory);
xlswrite('acmehistory.xlsx',historicPrices');
historicPrices = xlsread('acmehistory.xlsx',1)';

hVar = historicVar( ...
    percentage,d, ...
    strike, maturity, ...
    spot, historicPrices, ...
    r, vol);

[~,lower,upper] = monteCarloVarWithConfidence( ...
    95, ...
    percentage,d, ...
    strike, maturity, ...
    spot, drift, vol, ...
    r, ...
    nPaths);

fprintf('%d-day, %d%% Monte Carlo var is %d\n',  d, percentage, mVar );
fprintf('%d-day, %d%% Historic var is %d\n',  d, percentage, hVar );
fprintf('%d-day, %d%% Monte Carlo Expected Shortfall is %d\n',  d, percentage, es );
fprintf('True %d-day, %d%% var is %d\n', d, percentage, trueVar );
fprintf('%d-day, %d%% parametric var is %d\n',d,percentage,parametricVar);
fprintf('Lower confidence interval is %d\n',lower);
fprintf('Upper confidence interval is %d\n',upper);

assert (es > mVar);
assertApproxEqual( trueVar, mVar, 0.02 );
assertApproxEqual( trueVar, hVar, 0.02 );
assertApproxEqual( parametricVar, trueVar, 0.15 );

assert( lower<upper);
assert (trueVar>lower);
assert (trueVar<upper);

end

